<?php
/*
Plugin Name: Last Logins
Version: 1.0
Plugin URI: http://coffee2code.com/wp-plugins/last-logins
Author: Scott Reilly
Author URI: http://coffee2code.com
Description: Logs the dates and IP addresses of successful user logins and failed login attempts.

Compatible with WordPress 2.0+, 2.1+, 2.2+, 2.3+, and 2.5.

=>> Read the accompanying readme.txt file for more information.  Also, visit the plugin's homepage
=>> for more information and the latest updates

Features:
	* Records the IP address and date and time of the last successful login for each user account.
	* Records the IP address and date and time of the most recent failed login for each user account,
	  as well as a count of total number of failed logins since the last successful login.
	* Adds the submenu "Last Logins" under the "Users" admin menu which displays a table of the last login
	  and bad logins data recorded for all user accounts.
	* Adds the template tags last_login() and bad_logins() that can be inserted in theme templates to display
	  information regarding the logged-in users last login or bad login attempts since last login, respectively.
	* Each template tag allows for default information display, or can be passed a custom format string that
	  will be parsed for percent-tag substitution
	* Last login information, and bad logins since last login (if any had occurred), is summarized in the 
	  upper-right corner of the WP Admin pages.  (This feature is not compatible with the Hello Dolly plugin,
	  or any of its knockoffs)

Installation:

1. Download the file http://coffee2code.com/wp-plugins/last-logins.zip and unzip it into your 
/wp-content/plugins/ directory.
2. Activate the plugin through the 'Plugins' admin menu in WordPress
3. (Optional) If you wish, you can insert function call(s) to your templates to display information about
the last login and/or bad login attempts since the last successful login

[Note: users of versions of WordPress older than WP 2.2 may need to perform these additional steps:]
4. Go to the admin 'Users' page and click the new 'Last Logins' submenu link
5. Press the 'Install' button to create the database table needed for the plugin to work

*/

/*
Copyright (c) 2007-2008 by Scott Reilly (aka coffee2code)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation 
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, 
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the 
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

if (!class_exists('LastLogins')) :

$wpdb->last_logins = $wpdb->prefix . 'last_logins';

class LastLogins {
	var $last_logins_table = '';
	var $just_installed = false;
	var $bad_login_msg = '';
	
	function LastLogins() {
		global $wpdb;
		$this->last_logins_table = $wpdb->last_logins;

		$this->bad_login_msg = __('<strong>Ошибка</strong>: неверный пароль.'); // This is the default message WP uses

		/* Actions and filters */
		add_action('admin_menu', array(&$this, 'admin_add'));
		add_action('wp_login', array(&$this, 'log_login'));
		add_filter('login_errors', array(&$this, 'check_for_bad_login'));
		add_action('admin_footer', array(&$this, 'show_admin_note'));
		add_action('admin_head', array(&$this, 'show_css'));
	}
	
	function show_css() {
		echo "
			<style type='text/css'>
			#login_brief {
				position: absolute;
				top: 2.5em;
				margin: 0; padding: 0;
				right: 1em;
				font-size: 11px;
				color: #f1f1f1;
			}
			#login_brief p {
				margin:0; padding: 0;
			}
			#login_brief p.badlogins {
				color: #ee5544;
			}
			</style>
			";
	}
	function show_admin_note() {
		
	}
	
	function has_bad_logins($username = null) {
		$login = $this->last_login_for($username);
		return ($login && $login->last_bad_login_ip ? true : false);
	}

	function last_login_for($username = null) {		
		$user = !$username ? wp_get_current_user() : get_userdatabylogin($username);
		if ($user)
			return $this->query("SELECT * FROM $this->last_logins_table WHERE user_id = '$user->ID' LIMIT 1", 'row');
	}

	// Returns just the date and ip for the user's last login
	function last_login_date_and_ip($username = null) {
		$llogin = $this->last_login_for($username);
		$ip = $llogin->last_login2_ip;
		$date = $llogin->last_login2_at;
		if (!$ip) {
			$ip = $llogin->last_login_ip;
			$date = $llogin->last_login_at;
		}
		if (!$ip) $date = '';
		return array($date, $ip);
	}

	function check_for_bad_login($error_msg) {
		if (strpos($error_msg, $this->bad_login_msg) !== false) {
			$username = $_POST['log']; // WP default login fieldname
			$ip = preg_replace('/[^0-9., ]/', '', $_SERVER['REMOTE_ADDR']);
			$now = current_time('mysql');
			if ($r = $this->last_login_for($username)) {
				if (empty($r)) { print_r($r); die("r shouldn't be empty"); }
				$bad_logins = $r->bad_logins + 1;
				$this->query("UPDATE $this->last_logins_table
							  SET bad_logins = '$bad_logins', 
								  last_bad_login_ip = '$ip',
								  last_bad_login_at = '$now'
							  WHERE id = '$r->id'", 'query');
			} else {
				$user = get_userdatabylogin($username);
				if ($user) {
					$this->query("INSERT INTO $this->last_logins_table
							  	(user_id, last_bad_login_at, last_bad_login_ip, bad_logins)
							  	VALUES
							  	('$user->ID', '$now', '$ip', 1)", 'query');
				}
			}
		}
		return $error_msg;
	}
	
	function log_login($username) {
		$ip = preg_replace('/[^0-9., ]/', '', $_SERVER['REMOTE_ADDR']);
		$now = current_time('mysql');
		if ($r = $this->last_login_for($username)) {
			$more_sql = '';
			// If there was a previous login, then shift that data to the last_login2_* fields
			if ($r->last_login_at)
				$more_sql .= ", last_login2_ip = '$r->last_login_ip', last_login2_at = '$r->last_login_at'";
			// If the last successful login occurred after the last bad login, we don't need to preserve bad login info anymore.
			if ($r->last_login_at > $r->last_bad_login_at)
				$more_sql .= ", last_bad_login_at = '', last_bad_login_ip = '', bad_logins = 0";
			$this->query("UPDATE $this->last_logins_table
						  SET last_login_ip = '$ip',
							  last_login_at = '$now'$more_sql
						  WHERE id = '$r->id'", 'query');
		} else {
			$user = get_userdatabylogin($username);
			$this->query("INSERT INTO $this->last_logins_table
					  	(user_id, last_login_at, last_login_ip)
					  	VALUES
					  	('$user->ID', '$now', '$ip')", 'query');
		}
	}

	function is_installed() {
		$existing_table = $this->query("SHOW TABLES LIKE '{$this->last_logins_table}'");
		return !empty($existing_table);
	}

	function install() {
		if ($this->is_installed()) return;
		$sql = "CREATE TABLE {$this->last_logins_table} (
				id				bigint(20) unsigned NOT NULL auto_increment,
				user_id			bigint(20) unsigned NOT NULL,
				last_login_at	datetime NOT NULL default '0000-00-00 00:00:00',
				last_login_ip	varchar(100) NOT NULL default '',
				last_login2_at	datetime NOT NULL default '0000-00-00 00:00:00',
				last_login2_ip	varchar(100) NOT NULL default '',
				bad_logins		bigint(20) NOT NULL default '0',
				last_bad_login_at datetime NOT NULL default '0000-00-00 00:00:00',
				last_bad_login_ip varchar(100) NOT NULL default '',
				PRIMARY KEY (id),
				KEY user_id (user_id)
			)";
		$this->query($sql, 'query');
		$this->just_installed = true;
		update_option('c2c_last_logins_start', current_time('mysql'));
	}

	function query($sql, $type = 'results') {
		global $wpdb;
		if ('row' == $type) $ret = $wpdb->get_row($sql);
		elseif ('query' == $type) $ret = $wpdb->query($sql);
		elseif ('var' == $type) $ret = $wpdb->get_var($sql);
		else $ret = $wpdb->get_results($sql);
		if ('vars' == $type) $ret = $ret[0];
		return $ret;
	}

	function get_logins() {
		global $wpdb;
		return $this->query("SELECT * FROM $wpdb->users AS users LEFT JOIN $this->last_logins_table AS logins
											ON (users.ID = logins.user_id) WHERE 1=1 ORDER BY users.user_login ASC");
	}
	function get_earliest() {
		// This code figures out the oldest logged event currently in the table
		/*
		$min_login = $this->query("SELECT MIN(last_login_at) AS min_login FROM $this->last_logins_table 
									WHERE last_login_at IS NOT NULL AND last_login_at != '0000-00-00 00:00:00'", 'var');
		$min_login2 = $this->query("SELECT MIN(last_login2_at) AS min_login2 FROM $this->last_logins_table 
									WHERE last_login2_at IS NOT NULL AND last_login2_at != '0000-00-00 00:00:00'", 'var');
		$min_bad_login = $this->query("SELECT MIN(last_bad_login_at) AS min_bad_login FROM $this->last_logins_table 
									WHERE last_bad_login_at IS NOT NULL AND last_bad_login_at != '0000-00-00 00:00:00'", 'var');
		if ($min_login) $min = $min_login;
		if ($min_login2 && $min_login2 < $min) $min = $min_login2;
		if ($min_bad_login && $min_bad_login < $min) $min = $min_bag_login;
		return $min ? $min : 'not yet';
		*/
		return get_option('c2c_last_logins_start');
	}

	// Admin interface code
	function admin_add() {
		// Add menu under Options:
		add_submenu_page('users.php', 'Настройки мониторинга входа', 'Мониторинг входа', 10, basename(__FILE__), array(&$this, 'show_admin'));
	} // end admin_add()

	function show_admin() {
        // See if user has submitted form
        if ( isset($_POST['install_last_logins']) && ($_POST['install_last_logins'] == '1') ) {
                // Obtain and process fields.
                $this->install();
                if ($this->just_installed)
                        echo '<div class="updated"><p>Таблица last_logins создана.</p></div>';
                else
                        echo '<div class="error"><p>Таблица last_logins уже существует.</p></div>';
        }
	echo <<<END
		<div class='wrap'>
			<h2>Мониторинг</h2>
			<p>В журнале записываются даты и IP удачных и неудачных попыток входа.</p>
			<p>Неудавшиеся попытки входа записываются только если был один успешный вход.</p>
		</div>
		<div class='wrap'>
END;
	 	if (!$this->is_installed()) :
			$action_url = $_SERVER[PHP_SELF] . '?page=' . basename(__FILE__);
			echo <<<END
			<form name="install_last_logins" action="$action_url" method="post">
				Необходимо создать таблицу плагина в базе данных, для этого нажмите кнопку установки.
				<input type='hidden' name='install_last_logins' value='1' />
				<div class="submit"><input type="submit" name="Submit" value="Установить" /></div>
			</form>
END;
		else :
		$user_logins = $this->get_logins();
		$earliest = $this->get_earliest();
		echo <<<END
		<h2>Журнал</h2>
		<div style="text-align:right; font-size:x-small;">Журнал ведется с: $earliest</div>
		<table class='widefat'>
			<thead><tr>
				<th scope='col'>Логин</th>
				<th scope='col'>Последний вход</th>
				<th scope='col'>Последний IP</th>
				<th scope='col'># кол-во неудавшихся входов</th>
				<th scope='col'>Последний неудавшийся вход</th>
				<th scope='col'>Последний IP неудавшегося входа</th>
			</tr></thead>
			<tbody>
END;
			if (!$user_logins) :
				echo '<tr><td colspan="6">Еще никто не входил с момента установки плагина.</td></tr>';
			else :
				foreach ($user_logins as $user) {
					$class = !isset($class) || $class ? '' : ' class="alternate"';
					if ($user->last_login_at == '0000-00-00 00:00:00') $user->last_login_at = '';
					if ($user->last_bad_login_at == '0000-00-00 00:00:00') $user->last_bad_login_at = '';
					echo "<tr$class><td>$user->user_login</td>";
					if (!$user->last_login_at && !$user->last_bad_login_at) {
						echo "<td colspan='5'>Этот пользователь не пытался войти с тех пор, как плагин активирован.</td>";
					} else {
						echo "<td>$user->last_login_at</td><td>$user->last_login_ip</td>
							  <td>$user->bad_logins</td><td>$user->last_bad_login_at</td><td>$user->last_bad_login_ip</td>";
					}
					echo "</tr>";
				}
			endif;
			echo <<<END
			</tbody>
		</table>
END;
		endif;
		echo "</div>";
		$logo = get_option('siteurl') . '/wp-content/plugins/' . basename($_GET['page'], '.php') . '/c2c_minilogo.png';
		echo <<<END
		<style type="text/css">
			#c2c {
				text-align:center;
				color:#888;
				background-color:#ffffef;
				padding:5px 0 0;
				margin-top:12px;
				border-style:solid;
				border-color:#dadada;
				border-width:1px 0;
			}
			#c2c div {
				margin:0 auto;
				padding:5px 40px 0 0;
				width:45%;
				min-height:40px;
				background:url('$logo') no-repeat top right;
			}
			#c2c span {
				display:block;
				font-size:x-small;
			}
		</style>
		<div id='c2c' class='wrap'>
			<div>
			Автор плагина <a href="http://coffee2code.com" title="coffee2code.com">Scott Reilly, aka coffee2code</a>.
			<span><a href="http://coffee2code.com/donate" title="Отблагодарить автора">Понравился плагин?</a></span>
			</div>
		</div>
END;
	} // end show_admin()

} // end LastLogins

endif; // end if !class_exists()
if (class_exists('LastLogins')) :

//
// Template tags (for optional use in theme templates)
//

function last_login($custom_msg = '', $if_none = '') {
	global $last_logins;
	list($date,$ip) = $last_logins->last_login_date_and_ip();
	if (!$date) {
		if ($if_none) echo $if_none;
		return;
	}
	if ($custom_msg) {
		$custom_msg = str_replace('%ip%', $ip, $custom_msg);
		$custom_msg = str_replace('%date%', $date, $custom_msg);
		echo $custom_msg;
	} else {
		echo '<div class="last_login_message">';
		echo sprintf(__("Последний удачный вход в %s с IP %s."), $date, $ip);
		echo '</div>';
	}
}

function bad_logins($custom_msg = '', $if_none = '') {
	global $last_logins;
	if (!is_user_logged_in()) return;
	$last_login = $last_logins->last_login_for();
	if (!$last_login || !$last_login->last_bad_login_ip) {
		if ($if_none) echo $if_none;
		return;
	}
	if ($custom_msg) {
		$custom_msg = str_replace('%ip%', $last_login->last_bad_login_ip, $custom_msg);
		$custom_msg = str_replace('%date%', $last_login->last_bad_login_at, $custom_msg);
		$custom_msg = str_replace('%count%', $last_login->bad_logins, $custom_msg);
		echo $custom_msg;
	} else {
		echo '<div class="bad_login_message">';
		echo sprintf(__("%s неудавшихся попыток входа для вашего логина (после последнего удавшегося входа). "), $last_login->bad_logins);
		if ($last_login->bad_logins > 0)
			echo sprintf(__("Последний неудавшийся вход %s с %s."), $last_login->last_bad_login_at, $last_login->last_bad_login_ip);
		echo '</div>';
	}
}

// Get the ball rolling
$last_logins = new LastLogins();
// Actions and filters
if (isset($last_logins)) {
	register_activation_hook(__FILE__, array(&$last_logins, 'install'));
}

endif; // end if class_exists()
?>